%if 0%{?_version:1}
%define         _verstr      %{_version}
%else
%define         _verstr      1.7.0
%endif

Name:           prometheus
Version:        %{_verstr}
Release:        2%{?dist}
Summary:        Prometheus is an open-source systems monitoring which scrapes and stores time series data

Group:          System Environment/Daemons
License:        Apache 2.0
URL:            https://prometheus.io
Source0:        https://github.com/prometheus/%{name}/releases/download/v%{version}/%{name}-%{version}.linux-amd64.tar.gz
Source1:        %{name}.sysconfig
Source2:        %{name}.service
Source3:        %{name}.init
Source7:        %{name}.logrotate
BuildRoot:      %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

%if 0%{?fedora} >= 14 || 0%{?rhel} >= 7
BuildRequires:  systemd-units
Requires:       systemd
%else
Requires:       logrotate
%endif
Requires(pre): shadow-utils

%description
Prometheus is an open-source systems monitoring which scrapes and stores time series data

Prometheus's main features are:
    * a multi-dimensional data model (time series identified by metric name and key/value pairs)
    * a flexible query language to leverage this dimensionality
    * no reliance on distributed storage; single server nodes are autonomous
    * time series collection happens via a pull model over HTTP
    * pushing time series is supported via an intermediary gateway
    * targets are discovered via service discovery or static configuration
    * multiple modes of graphing and dashboarding support

%prep
%setup -q -n %{name}-%{version}.linux-amd64

%install
mkdir -p %{buildroot}/%{_localstatedir}/log/prometheus
mkdir -p %{buildroot}/%{_bindir}
cp prometheus %{buildroot}/%{_bindir}
cp promtool %{buildroot}/%{_bindir}
mkdir -p %{buildroot}/%{_sysconfdir}/%{name}
cp prometheus.yml %{buildroot}/%{_sysconfdir}/%{name}/
mkdir -p %{buildroot}/%{_sysconfdir}/sysconfig
cp %{SOURCE1} %{buildroot}/%{_sysconfdir}/sysconfig/%{name}
mkdir -p %{buildroot}/%{_sharedstatedir}/%{name}
mkdir -p %{buildroot}/%{_datadir}/%{name}
mv consoles/index.html.example consoles/index.html 
sed -i "s|index.html.example|index.html|g" console_libraries/menu.lib
cp -r consoles console_libraries %{buildroot}/%{_prefix}/share/%{name}

%if 0%{?fedora} >= 14 || 0%{?rhel} >= 7
mkdir -p %{buildroot}/%{_unitdir}
cp %{SOURCE2} %{buildroot}/%{_unitdir}/
%else
mkdir -p %{buildroot}/%{_initrddir}
mkdir -p %{buildroot}/%{_sysconfdir}/logrotate.d
cp %{SOURCE3} %{buildroot}/%{_initrddir}/prometheus
cp %{SOURCE7} %{buildroot}/%{_sysconfdir}/logrotate.d/%{name}
%endif

%pre
getent group prometheus >/dev/null || groupadd -r prometheus
getent passwd prometheus >/dev/null || \
    useradd -r -g prometheus -d /var/lib/prometheus -s /sbin/nologin \
    -c "prometheus.io user" prometheus
exit 0

%if 0%{?fedora} >= 14 || 0%{?rhel} >= 7
%post
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service
%else
%post
/sbin/chkconfig --add %{name}

%preun
if [ "$1" = 0 ] ; then
    /sbin/service %{name} stop >/dev/null 2>&1
    /sbin/chkconfig --del %{name}
fi
%endif

%clean
rm -rf %{buildroot}


%files
%defattr(-,root,root,-)
%dir %attr(750, root, prometheus) %{_sysconfdir}/%{name}
%attr(640, root, prometheus) %{_sysconfdir}/%{name}/prometheus.yml
%dir %attr(750, prometheus, prometheus) %{_sharedstatedir}/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%if 0%{?fedora} >= 14 || 0%{?rhel} >= 7
%{_unitdir}/%{name}.service
%else
%attr(755, root, root) %{_initrddir}/%{name}
%{_sysconfdir}/logrotate.d/%{name}
%endif
%attr(755, root, root) %{_bindir}/prometheus
%attr(755, root, root) %{_bindir}/promtool
%attr(-, root, prometheus) %{_prefix}/share/%{name}
%dir %attr(700, prometheus, prometheus) %{_localstatedir}/log/prometheus
%doc LICENSE NOTICE


%changelog
* Mon Jun 12 2017 Teguh DC <dheche@fedoraproject.org> - 1.7.0-1
- Initial rpm package
